@@ -12,16 +12,14 @@ def create_dir_if_not_exist(dirpath: str):
 
 
 def run():
-    src1 = os.path.join(os.path.dirname(__file__), os.path.join(os.path.join('templates', 'admin'), 'csv_form.html'))
+    src1 = os.path.join(os.path.dirname(__file__), 'templates', 'admin', 'csv_form.html')
     dst1 = os.path.join('templates', 'admin')
 
-    src2 = os.path.join(os.path.dirname(__file__),
-                       os.path.join(os.path.join('templates', 'entities'), 'mychange_list.html'))
-    dst2 = os.path.join('templates', 'entities')
+    src2 = os.path.join(os.path.dirname(__file__), 'templates', 'entities', 'mychange_list.html')
+    dst2 = os.path.join('templates', 'entities', 'mychange_list.html')
 
-    src3 = os.path.join(os.path.dirname(__file__),
-                       os.path.join(os.path.join('templates', 'entities'), 'basechange_list.html'))
-    dst3 = os.path.join('templates', 'entities')
+    src3 = os.path.join(os.path.dirname(__file__), 'templates', 'entities', 'basechange_list.html')
+    dst3 = os.path.join('templates', 'entities', 'basechange_list.html')
 
     if os.path.exists(dst1) and os.path.exists(dst2) and os.path.exists(dst3):
         return
