@@ -56,7 +56,7 @@ class Pagination(PageNumberPagination):
     max_page_size = int(PAGINATION_SETTINGS.get('max_page_size'))
 
 
-class BaseList(ListModelMixin, RetrieveModelMixin, GenericAPIView):
+class BaseListView(ListModelMixin, RetrieveModelMixin, GenericAPIView):
     """
     * API: BaseModel的ListView和RetrieveView接口
 
@@ -188,6 +188,9 @@ class BaseList(ListModelMixin, RetrieveModelMixin, GenericAPIView):
         return ret
 
 
+BaseList = BaseListView     # 向下兼容
+
+
 def paginate_qsls_to_dcls(qsls, serializer, page: int, per_page=16):
     """
     * 手动分页函数
